[Buildbot-commits] buildbot/buildbot/test test_vc.py,1.42,1.43

Brian Warner warner at users.sourceforge.net
Mon Oct 24 22:42:05 UTC 2005


Update of /cvsroot/buildbot/buildbot/buildbot/test
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv4679/buildbot/test

Modified Files:
	test_vc.py 
Log Message:
Revision: arch at buildbot.sf.net--2004/buildbot--dev--0--patch-380
Creator:  Brian Warner <warner at lothar.com>

s/base_url/baseURL/ and s/default_branch/defaultBranch/ for SVN+Darcs

	* buildbot/process/step.py (SVN.__init__): change 'base_url' and
	'default_branch' argument names to 'baseURL' and 'defaultBranch',
	for consistency with other BuildStep arguments that use camelCase.
	Well, at least more of them use camelCase (like flunkOnWarnings)
	than don't.. I wish I'd picked one style and stuck with it
	earlier. Annoying, but it's best done before the release, since
	these arguments didn't exist at all in 0.6.6 .
	(Darcs): same
	* buildbot/test/test_vc.py (SVN.testCheckout): same
	(Darcs.testPatch): same
	* docs/buildbot.texinfo (SVN): document the change
	(Darcs): same, add some build-on-branch docs
	* docs/examples/twisted_master.cfg: match change


Index: test_vc.py
===================================================================
RCS file: /cvsroot/buildbot/buildbot/buildbot/test/test_vc.py,v
retrieving revision 1.42
retrieving revision 1.43
diff -u -d -r1.42 -r1.43
--- test_vc.py	16 Aug 2005 00:23:53 -0000	1.42
+++ test_vc.py	24 Oct 2005 22:42:03 -0000	1.43
@@ -1108,21 +1108,21 @@
 
     def testCheckout(self):
         # we verify this one with the svnurl style of vcargs. We test the
         # base_url/default_branch style in testPatch and testBranch.
         self.vcargs = { 'svnurl': self.svnurl_trunk }
         d = self.do_vc()
         return maybeWait(d)
 
     def testPatch(self):
-        self.vcargs = { 'base_url': self.svnurl + "/",
-                        'default_branch': "sample/trunk",
+        self.vcargs = { 'baseURL': self.svnurl + "/",
+                        'defaultBranch': "sample/trunk",
                         }
         d = self.do_patch()
         return maybeWait(d)
 
     def testBranch(self):
-        self.vcargs = { 'base_url': self.svnurl + "/",
-                        'default_branch': "sample/trunk",
+        self.vcargs = { 'baseURL': self.svnurl + "/",
+                        'defaultBranch': "sample/trunk",
                         }
         d = self.do_branch()
         return maybeWait(d)
@@ -1130,8 +1130,8 @@
     def testTry(self):
         # extract the base revision and patch from a modified tree, use it to
         # create the same contents on the buildslave
-        self.vcargs = { 'base_url': self.svnurl + "/",
-                        'default_branch': "sample/trunk",
+        self.vcargs = { 'baseURL': self.svnurl + "/",
+                        'defaultBranch': "sample/trunk",
                         }
         d = self.do_getpatch()
         return maybeWait(d)
@@ -1238,14 +1238,14 @@
         return maybeWait(d)
 
     def testPatch(self):
-        self.vcargs = { 'base_url': self.darcs_base + "/",
-                        'default_branch': "trunk" }
+        self.vcargs = { 'baseURL': self.darcs_base + "/",
+                        'defaultBranch': "trunk" }
         d = self.do_patch()
         return maybeWait(d)
 
     def testBranch(self):
-        self.vcargs = { 'base_url': self.darcs_base + "/",
-                        'default_branch': "trunk" }
+        self.vcargs = { 'baseURL': self.darcs_base + "/",
+                        'defaultBranch': "trunk" }
         d = self.do_branch()
         return maybeWait(d)
 
@@ -1259,8 +1259,8 @@
         return maybeWait(d)
         
     def testTry(self):
-        self.vcargs = { 'base_url': self.darcs_base + "/",
-                        'default_branch': "trunk" }
+        self.vcargs = { 'baseURL': self.darcs_base + "/",
+                        'defaultBranch': "trunk" }
         d = self.do_getpatch()
         return maybeWait(d)
 
@@ -1108,21 +1108,21 @@
     def testCheckout(self):
         # we verify this one with the svnurl style of vcargs. We test the
-        # base_url/default_branch style in testPatch and testBranch.
+        # baseURL/defaultBranch style in testPatch and testBranch.
         self.vcargs = { 'svnurl': self.svnurl_trunk }
         d = self.do_vc()





More information about the Commits mailing list